@@ -1,12 +1,10 @@
 curvemean <- function(
-ml, 
-type = c("fluo", "expval"), 
-mean = c("amean", "gmean", "hmean"),
+ml,         
+mean = c("cmean1", "cmean2", "amean", "gmean", "hmean"),
 which = 1, 
 plot = TRUE)
 {
-  mean <- match.arg(mean)
-  type <- match.arg(type)
+  mean <- match.arg(mean)      
   REF.fluo <- fitted(ml[[which]])   
   DATA <- ml[[which]]$DATA[, 1] 
   ml2 <- ml[-which]       
@@ -20,29 +18,22 @@ plot = TRUE)
   DATA <- DATA[COMPL, ]    
   
   gmean <- function(x) prod(x, na.rm = TRUE)^(1/length(x[!is.na(x)]))
-  hmean <- function(x) length(x[!is.na(x)])/sum(1/x, na.rm = TRUE)    
-  
+  hmean <- function(x) length(x[!is.na(x)])/sum(1/x, na.rm = TRUE) 
+  cmean <- function(x, E) (-log(mean(E^-x, na.rm = TRUE))/log(E))
+      
   MEAN <- vector(length = nrow(DATA))
   CYCS <- DATA[, 1]
-  EFFS <- sapply(ml, function(x) eff(x)$eff.y[CYCS * 100])  
-  
+  EFFS <- sapply(ml, function(x) eff(x)$eff.y[CYCS * 100])    
+    
   for (i in 1:nrow(DATA)) { 
     X <- DATA[i, ]
-    if (type == "fluo") {
-      MEAN[i] <- switch(mean, amean = mean(X, na.rm = TRUE),
-                              gmean = gmean(X),
-                              hmean = hmean(X))
-    } else {
-      EFF <- mean(EFFS[i, ], na.rm = TRUE)
-      max.X <- max(X, na.rm = TRUE)      
-      temp1 <- abs(max.X - X)
-      temp2 <- switch(mean, amean = mean(EFF^temp1, na.rm = TRUE),
-                            gmean = gmean(EFF^temp1),
-                            hmean = hmean(EFF^temp1))
-      temp3 <- logb(temp2, EFF)
-      MEAN[i] <- max.X - temp3 
-     }                                
-  }    
+    E <- mean(EFFS[i, ], na.rm = TRUE)
+    MEAN[i] <- switch(mean, amean = mean(X, na.rm = TRUE),
+                            gmean = gmean(X),
+                            hmean = hmean(X),
+                            cmean1 = cmean(X, 2),
+                            cmean2 = cmean(X, E))  
+  }      
  
   MEAN[!is.finite(MEAN)] <- NA
   RES <- cbind(MEAN, REF.fluo[COMPL])    
