@@ -9,38 +9,39 @@ nls.method = "port",
 start = NULL,
 robust = FALSE,
 control = nls.control(),
-weights = NULL, 
 ...)
 {            
   require(rgenoud, quietly = TRUE)
   require(minpack.lm, quietly = TRUE)     
-  options(warn = -1)    
-  if (is.null(weights)) wts <- rep(1, nrow(data)) else wts <- weights/max(weights, na.rm = TRUE)      
-  
-  Cycles <- data[, cyc]          
-  Fluo <- data[, fluo]        
-    
-  DATA <- as.data.frame(cbind(Cycles, Fluo))     
+  options(warn = -1)
+
+  Cycles <- data[, cyc]
+  Fluo <- data[, fluo]
+  DATA <- as.data.frame(cbind(Cycles, Fluo))
+  compl <- complete.cases(Fluo)
+  Cycles <- Cycles[compl]
+  Fluo <- Fluo[compl]
+
   if (is.null(start)) ssVal <- model$ssFct(Cycles, Fluo)
-   else ssVal <- start      
+   else ssVal <- start
     
   ssValMat <- NULL
   ssValMat <- rbind(ssValMat, c("start", ssVal))
   
   FCT <- function(x) {     
-    SSR <- sum(wts * ((Fluo - model$fct(Cycles, x))^2))    
+    SSR <- sum((Fluo - model$fct(Cycles, x))^2)
     SSR       
   }    
   
   FCT2 <- function(x) {     
-    RESID <- wts * (Fluo - model$fct(Cycles, x))      
+    RESID <- Fluo - model$fct(Cycles, x)
     RESID       
   }                         
   
   if (do.optim) {
     for (i in opt.method) {      
       if (i == "LM") {
-        OPTIM <- nls.lm(ssVal, FCT2, ...)              
+        OPTIM <- nls.lm(ssVal, FCT2, ...)
       }
       if (i != "GA" && i != "LM") {
         OPTIM <- try(optim(ssVal, FCT, method = i, hessian = TRUE, control = list(parscale = abs(ssVal), maxit = 50000), ...), silent = TRUE)
@@ -60,11 +61,10 @@ weights = NULL,
   names(ssVal) <- model$parnames    
   control$maxiter <-  50000
   control$warnOnly <-  TRUE
-  
 
   if (!robust) NLS <- try(nls(as.formula(model$expr), data = DATA, start = as.list(ssVal), model = TRUE,
-                          algorithm = nls.method, control = control, weights = wts, ...), silent = TRUE)
-   else NLS <- try(qpcR:::rnls(as.formula(model$expr), data = DATA, start = as.list(ssVal), control = control, weights = wts, ...), silent = TRUE)
+                          algorithm = nls.method, control = control, ...), silent = TRUE)
+   else NLS <- try(qpcR:::rnls(as.formula(model$expr), data = DATA, start = as.list(ssVal), control = control, ...), silent = TRUE)
     
   if (inherits(NLS, "try-error")) stop("There was a problem during 'nls'. Try other method...")                             
     
@@ -74,7 +74,6 @@ weights = NULL,
   NLS$MODEL <- model  
   NLS$parMat <- ssValMat
   NLS$opt.method <- opt.method
-  NLS$weights <- wts   
   
   CALL <- as.list(NLS$call)     
   CALL$formula <- as.formula(model$expr)
@@ -82,6 +81,7 @@ weights = NULL,
   NLS$call <- as.call(CALL)
   NLS$call2 <- match.call()
   assign("DATA", DATA, envir = globalenv())
+  NLS$names <- names(data)[fluo]
 
   class(NLS) <- c("pcrfit", "nls")
   return(NLS)      
